#ifndef __RCSID
#define __RCSID(x) static const char __rcsid[] __attribute__((__used__)) = x
#endif

#ifndef __dead
#define __dead __attribute__((__noreturn__))
#endif

#ifdef NEED_STRTONUM
extern long long strtonum(const char *, long long, long long, const char **);
#endif
